@@ -5,17 +5,17 @@ import requests
 import pkg_resources
 import platform
 from rich import print
+from rich.prompt import Confirm
 from rich.table import Table
 import shutil
 import sys
 import typer
 import zipfile
 from zoneinfo import ZoneInfo
-from rich.prompt import Confirm
 
 from tasknode.auth import get_valid_token
 from tasknode.constants import API_URL
-
+from tasknode.utils import format_file_size, format_time
 
 def submit(
     script: str = typer.Argument(
@@ -46,7 +46,7 @@ def submit(
     deploy_full = Confirm.ask(
         "\nDoes your script depend on other files in this directory (like modules, data files, or config files)?\n"
         "[cyan]•[/cyan] Yes = deploy entire directory\n"
-        "[cyan]•[/cyan] No = deploy single script only (for standalone scripts) [dim](default)[/dim]\n",
+        "[cyan]•[/cyan] No = deploy single script only (for standalone scripts) [cyan](default)[/cyan]\n",
         default=False,
     )
 
@@ -115,7 +115,7 @@ def submit(
     if os.path.exists(requirements_file):
         use_requirements_file = Confirm.ask(
             f"\nA {requirements_file} file was found. How would you like to handle dependencies?\n"
-            "[cyan]•[/cyan] Yes = use requirements.txt file [dim](default)[/dim]\n"
+            "[cyan]•[/cyan] Yes = use requirements.txt file [cyan](default)[/cyan]\n"
             "[cyan]•[/cyan] No = use current environment's installed packages (like pip freeze)\n",
             default=True,
         )
@@ -198,15 +198,6 @@ def submit(
     except requests.exceptions.RequestException as e:
         typer.echo(f"Upload failed: {str(e)}", err=True)
         raise typer.Exit(1)
-    finally:
-        # Clean up temporary files
-        try:
-            if os.path.exists("tasknode_deploy"):
-                shutil.rmtree("tasknode_deploy")
-            if os.path.exists("tasknode_deploy.zip"):
-                os.remove("tasknode_deploy.zip")
-        except Exception as e:
-            typer.echo(f"Warning: Error during cleanup: {str(e)}", err=True)
 
 
 def should_copy(path, exclude_patterns):
@@ -252,20 +243,22 @@ def jobs(offset: int = 0):
             title += f" ({offset + 1} - {end_index} of {total_job_count})"
 
         table = Table(title=title)
+        table.add_column("Index", style="bold")
         table.add_column("Job ID", style="cyan")
         table.add_column("Status", style="magenta")
         table.add_column("Created At", style="green")
         table.add_column("Updated At", style="yellow")
+        table.add_column("Runtime", style="blue")
 
         # Add rows to the table
-        for job in jobs_data["jobs"]:
+        for index, job in enumerate(jobs_data["jobs"], start=offset + 1):
             created_dt = datetime.fromisoformat(job["created_at"]).replace(tzinfo=ZoneInfo("UTC"))
             updated_dt = datetime.fromisoformat(job["updated_at"]).replace(tzinfo=ZoneInfo("UTC"))
 
             created_at = created_dt.astimezone().strftime("%Y-%m-%d %H:%M:%S%z")
             updated_at = updated_dt.astimezone().strftime("%Y-%m-%d %H:%M:%S%z")
 
-            table.add_row(str(job["id"]), job["status"], created_at, updated_at)
+            table.add_row(str(index), str(job["id"]), job["status"], created_at, updated_at, format_time(job["runtime"]))
 
         # Print the table
         print("")
@@ -275,6 +268,8 @@ def jobs(offset: int = 0):
         if end_index < total_job_count:
             next_offset = offset + limit
             print(f"To see the next page, run: `tasknode list-jobs --offset {next_offset}`")
+            print("\nTo get details for a specific job, run: `tasknode job <job_id || index>`")
+            print("(for example `tasknode job 1` will get you the most recently created job and `tasknode job faa868f9-b0cb-4792-b176-64575dab86a7` will get you the job with that ID)")
 
     except requests.exceptions.RequestException as e:
         typer.echo(f"Failed to fetch jobs: {str(e)}", err=True)
@@ -330,3 +325,54 @@ def create_zip(source_path, output_path):
                 file_path = os.path.join(root, file)
                 arcname = os.path.relpath(file_path, source_path)
                 zipf.write(file_path, arcname)
+
+
+def get_job_details(job_id: str):
+    """
+    Get details of a specific TaskNode job using either a job ID (UUID) or job index number.
+    """
+    try:
+        access_token = get_valid_token()
+    except Exception as e:
+        typer.echo(f"Authentication error: {str(e)}", err=True)
+        raise typer.Exit(1)
+
+    try:
+        # Fetch job details using either UUID or index number
+        response = requests.get(
+            f"{API_URL}/api/v1/jobs/get/{job_id}",
+            headers={"Authorization": f"Bearer {access_token}"},
+        )
+
+        if response.status_code == 404:
+            typer.echo(f"Job not found", err=True)
+            raise typer.Exit(1)
+
+        response.raise_for_status()
+        job_data = response.json()
+
+        # Display job details
+        print(f"\n[bold]Job ID:[/bold] {job_data['id']}")
+        print(f"[bold]Status:[/bold] {job_data['status']}")
+        print(f"[bold]Runtime:[/bold] {format_time(job_data['runtime'])}")
+        print(f"[bold]Created At:[/bold] {job_data['created_at']}")
+        print(f"[bold]Updated At:[/bold] {job_data['updated_at']}\n")
+
+        # Display files associated with the job
+        if job_data['files']:
+            table = Table(title="Generated Files")
+            table.add_column("File Name", style="cyan")
+            table.add_column("File Size", style="magenta")
+            table.add_column("Timestamp", style="green")
+
+            for file in job_data['files']:
+                file_size = format_file_size(file['file_size'])
+                table.add_row(file['file_name'], file_size, file['file_timestamp'])
+
+            print(table)
+        else:
+            print("No files associated with this job.")
+
+    except requests.exceptions.RequestException as e:
+        typer.echo(f"Failed to fetch job details: {str(e)}", err=True)
+        raise typer.Exit(1)
